@@ -13,9 +13,9 @@
     by providing train, evaluation and source separation action.
 """
 
-__email__ = 'spleeter@deezer.com'
-__author__ = 'Deezer Research'
-__license__ = 'MIT License'
+__email__ = "spleeter@deezer.com"
+__author__ = "Deezer Research"
+__license__ = "MIT License"
 
 
 class SpleeterError(Exception):
